#!/bin/sh
#
# Script to set up and run Gmaj for the gene-conversion pipeline,
# showing many-to-many orthologs instead of conversion evidence.
# It uses the exons2underlays tool in the package's bin directory.
#

JAR=../gmaj.jar
MTM_DIR=ortho.d/many-to-many-ortho.d
CHAIN_DIR=ortho.d/ch_pair.d
EXON_DIR=exons.d
PARAM_FILE=./gmaj.param
PREFS_FILE=./gmaj.prefs
HEAP_MB=200
E2U="../bin/exons2underlays -laj -fexon LightBlue -intron LightYellow"
TITLE="Many-to-many orthologs vs. all chained alignments"

# ---- get arguments ----

if [ $# -ne 2 ]; then
	echo "Usage:  gmaj-mtm.sh refseq_name seq2_name"
	exit 1
fi

REFNAME=$1
SEQ2NAME=$2

# ---- set up data files ----

rm -f many-to-many.maf
ln -s $MTM_DIR/$REFNAME.$SEQ2NAME.maf many-to-many.maf

rm -f chained.maf
ln -s $CHAIN_DIR/$REFNAME.$SEQ2NAME.maf chained.maf

if test -f $EXON_DIR/$REFNAME.underlays; then
	echo "Using existing underlay file $EXON_DIR/$REFNAME.underlays"
else
	$E2U $EXON_DIR/$REFNAME.exons > $EXON_DIR/$REFNAME.underlays
fi

if test -f $EXON_DIR/$SEQ2NAME.underlays; then
	echo "Using existing underlay file $EXON_DIR/$SEQ2NAME.underlays"
else
	$E2U $EXON_DIR/$SEQ2NAME.exons > $EXON_DIR/$SEQ2NAME.underlays
fi

# ---- write parameters file ----

rm -f $PARAM_FILE

echo "#:gmaj"                                    > $PARAM_FILE
echo                                             >> $PARAM_FILE
echo "title = \"$TITLE\""                        >> $PARAM_FILE
echo "alignfile = many-to-many.maf chained.maf"  >> $PARAM_FILE
echo "refseq = $REFNAME"                         >> $PARAM_FILE
echo                                             >> $PARAM_FILE
echo "seq 0:"                                    >> $PARAM_FILE
echo "seqname   = $REFNAME"                      >> $PARAM_FILE
echo "exons     = $EXON_DIR/$REFNAME.exons"      >> $PARAM_FILE
echo "underlays = $EXON_DIR/$REFNAME.underlays"  >> $PARAM_FILE
echo                                             >> $PARAM_FILE
echo "seq 1:"                                    >> $PARAM_FILE
echo "seqname   = $SEQ2NAME"                     >> $PARAM_FILE
echo "exons     = $EXON_DIR/$SEQ2NAME.exons"     >> $PARAM_FILE
echo "underlays = $EXON_DIR/$SEQ2NAME.underlays" >> $PARAM_FILE
echo                                             >> $PARAM_FILE

# ---- run Gmaj with extra heap space, and user prefs if present ----

if test -f $PREFS_FILE; then
	exec java -Xmx${HEAP_MB}m -jar $JAR -prefs $PREFS_FILE $PARAM_FILE
else
	exec java -Xmx${HEAP_MB}m -jar $JAR $PARAM_FILE
fi

