#!/bin/sh
#
# Script to set up and run Gmaj for the gene-conversion pipeline.
#

JAR=../gmaj.jar
#SELF_DIR=ortho.d/self.d    # use $REFNAME.d/$REFNAME.maf instead (per Giltae)
ORTH_DIR=ortho.d/ch_pair.d
#ORTH_DIR=ortho.d/one-to-many-ortho.d
EXON_DIR=exons.d
GC_FILE=./all.gc
PARAM_FILE=./gmaj.param
PREFS_FILE=./gmaj.prefs
HEAP_MB=200

# ---- get arguments ----

if [ $# -lt 1 ] || [ $# -gt 3 ]; then
	echo "Usage:  gmaj.sh refseq_name [genomic_offset] [\"title\"]"
	exit 1
fi

REFNAME=$1
OFFSET=0
TITLE="Gene conversions in $1"

if [ $# -gt 1 ]; then
	OFFSET=$2
fi
if [ $# -gt 2 ]; then
	TITLE=$3
fi

# ---- write parameters file ----

rm -f $PARAM_FILE
SELFMAF=$REFNAME.d/$REFNAME.remove_repeats.maf
#ORTHMAFS=`echo $ORTH_DIR/$REFNAME.*.maf`
ORTHMAFS=""
SEQS=`cat $GC_FILE | grep '^[ \t]*(' -m 1 | tr -s '(),;\[\]0-9' ' '`
for seq in $SEQS; do
	if [ $seq != $REFNAME ]; then
		ORTHMAFS="$ORTHMAFS $ORTH_DIR/$REFNAME.$seq.maf"
	fi
done

echo "#:gmaj"                                > $PARAM_FILE
echo                                         >> $PARAM_FILE
echo "title = \"$TITLE\""                    >> $PARAM_FILE
echo "alignfile = $SELFMAF $ORTHMAFS"        >> $PARAM_FILE
echo "refseq = $REFNAME"                     >> $PARAM_FILE
echo "geneconv = $GC_FILE"                   >> $PARAM_FILE
echo "nowarn = geneconv_nomaf"               >> $PARAM_FILE
echo                                         >> $PARAM_FILE
echo "seq 0:"                                >> $PARAM_FILE
echo "seqname = $REFNAME"                    >> $PARAM_FILE
echo "exons   = $EXON_DIR/$REFNAME.exons"    >> $PARAM_FILE
echo "offset  = $OFFSET"                     >> $PARAM_FILE
echo                                         >> $PARAM_FILE
echo "seq 1:"                                >> $PARAM_FILE
echo "seqname = $REFNAME"                    >> $PARAM_FILE
echo "exons   = $EXON_DIR/$REFNAME.exons"    >> $PARAM_FILE
echo "offset  = $OFFSET"                     >> $PARAM_FILE
echo                                         >> $PARAM_FILE

# ---- run Gmaj with extra heap space, and user prefs if present ----

if test -f $PREFS_FILE; then
	exec java -Xmx${HEAP_MB}m -jar $JAR -prefs $PREFS_FILE $PARAM_FILE
else
	exec java -Xmx${HEAP_MB}m -jar $JAR $PARAM_FILE
fi

